sci.ctx-store

Canonical place for projects to store, update and retrieve a context. This can be used by projects that need to expose their context to functions. SCI binds this dynamic var to the evaluating context during eval-form. Projects like sci.configs assume this var to be set in some of their functions.

Canonical place for projects to store, update and retrieve a context.
This can be used by projects that need to expose their context to
functions. SCI binds this dynamic var to the evaluating context during
`eval-form`. Projects like `sci.configs` assume this var to be set in
some of their functions.
raw docstring

get-ctxclj/s

(get-ctx)

Retrieve stored ctx or throw an exception.

Retrieve stored ctx or throw an exception.
sourceraw docstring

reset-ctx!clj/s

(reset-ctx! ctx)

Store ctx

Store `ctx`
sourceraw docstring

swap-ctx!clj/s

(swap-ctx! f & args)

Update ctx using f and args

Update `ctx` using `f` and `args`
sourceraw docstring

with-ctxclj/smacro

(with-ctx ctx & body)

Bind ctx during execution of body.

Bind `ctx` during execution of body.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries