Canonical place for projects to store, update and retrieve a context.
This can be used by projects that need to expose their context to
functions. SCI binds this dynamic var to the evaluating context during
eval-form. Projects like sci.configs assume this var to be set in
some of their functions.
Canonical place for projects to store, update and retrieve a context. This can be used by projects that need to expose their context to functions. SCI binds this dynamic var to the evaluating context during `eval-form`. Projects like `sci.configs` assume this var to be set in some of their functions.
(get-ctx)Retrieve stored ctx or throw an exception.
Retrieve stored ctx or throw an exception.
(swap-ctx! f & args)Update ctx using f and args
Update `ctx` using `f` and `args`
(with-ctx ctx & body)Bind ctx during execution of body.
Bind `ctx` during execution of body.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |